@@ -3,6 +3,8 @@ from django.contrib.auth.models import User
 from django.db.models import Q
 
 from utilities.filters import BaseFilterSet
+from dcim.models import Device
+from virtualization.models import VirtualMachine
 from .models import Category, VMWorkLog, DeviceWorkLog
 from .choices import *
 
@@ -28,6 +30,12 @@ class DeviceWorkLogFilterSet(BaseFilterSet):
         to_field_name='id',
         label='Category',
     )
+    device = django_filters.ModelMultipleChoiceFilter(
+        field_name='device__id',
+        queryset=Device.objects.all(),
+        to_field_name='id',
+        label='Device',
+    )
     internal_only=django_filters.MultipleChoiceFilter(
         choices=InternalOnlyChoices,
         null_value=None
@@ -71,6 +79,12 @@ class VMWorkLogFilterSet(BaseFilterSet):
         to_field_name='id',
         label='Category',
     )
+    vm = django_filters.ModelMultipleChoiceFilter(
+        field_name='vm__id',
+        queryset=VirtualMachine.objects.all(),
+        to_field_name='id',
+        label='VM'
+    )
     internal_only = django_filters.MultipleChoiceFilter(
         choices=InternalOnlyChoices,
         null_value=None
